/* $Id: compile.h 1270 2006-07-16 19:46:57Z holger $
 *
 * HoiChess/compile.h
 *
 * Copyright (C) 2004-2006 Holger Ruckdeschel <holger@hoicher.de>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 */
#ifndef COMPILE_H
#define COMPILE_H

#define COMPILE_DATE	__DATE__ " " __TIME__

#if defined(__GNUC__)
# define COMPILER	"GCC " __VERSION__
#elif defined(__INTEL_COMPILER)
# define COMPILER	"ICC"
#else
# define COMPILER	"unknown"
#endif

#endif /* COMPILE_H */
